# dispy: Admin Cluster(s)

# of Nodes : |
CPU Time Sec : |
Jobs Done : |

Nodes
| IP Address | Name | CPUs | Busy | Available | Jobs Done | CPU Time Sec | Last Update
--- | --- | --- | --- | --- | --- | --- | --- | ---
CPU | Memory | Swap | Disk

Poll Interval Seconds : | Now |
Node : | Port : |
Cluster Admin Secret : | Show |
Sort Nodes by : |  |
Service Time of Selected Nodes : | Now |
CPUs of Selected Nodes : | All |